==> open-xchange-documents-backend_7.10.3.orig.tar.bz2: open-xchange-documents-backend-7.10.3/com.openexchange.office.rt2.core/src/com/openexchange/office/rt2/core/doc/EditRightsHelper.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.rt2.core.doc;

import org.apache.commons.lang3.Validate;
import org.json.JSONObject;
import com.openexchange.office.rt2.protocol.RT2Message;
import com.openexchange.office.rt2.protocol.value.RT2MessageType;

/**
 * Helper class to retrieve action and value from a "editrights"
 * request.
 *
 * @author Carsten Driesner
 *
 */
public class EditRightsHelper
{
	//-------------------------------------------------------------------------
	public static final String ACTION_EDITRIGHTS_REQUESTS = "request";

	//-------------------------------------------------------------------------
	public static final String ACTION_EDITRIGHTS_APPROVED = "approved";

	//-------------------------------------------------------------------------
	public static final String ACTION_EDITRIGHTS_DECLINED = "declined";

	//-------------------------------------------------------------------------
	public static final String ACTION_EDITRIGHTS_FORCE    = "force";

	//-------------------------------------------------------------------------
	public static final String ACTION_EDITRIGHTS_ALL      = "@ALL";

	//-------------------------------------------------------------------------
	public static String getAction(final RT2Message aMsg) throws Exception
	{
		Validate.notNull(aMsg);

		if (RT2MessageType.REQUEST_EDITRIGHTS.equals(aMsg.getType()))
			return aMsg.getBody().getString(MessageProperties.PROP_ACTION);
		throw new IllegalArgumentException("RT2Message is not a REQUEST_EDITRIGHTS");
	}

	//-------------------------------------------------------------------------
	public static String getActionValue(final RT2Message aMsg) throws Exception
	{
		Validate.notNull(aMsg);

		if (RT2MessageType.REQUEST_EDITRIGHTS.equals(aMsg.getType()))
			return aMsg.getBody().optString(MessageProperties.PROP_VALUE, null);
		throw new IllegalArgumentException("RT2Message is not a REQUEST_EDITRIGHTS");
	}

	//-------------------------------------------------------------------------
	public static String getAction(final JSONObject aMsgBody) throws Exception
	{
		Validate.notNull(aMsgBody);

		return aMsgBody.getString(MessageProperties.PROP_ACTION);
	}

	//-------------------------------------------------------------------------
	public static String getActionValue(final JSONObject aMsgBody) throws Exception
	{
		Validate.notNull(aMsgBody);

		return aMsgBody.optString(MessageProperties.PROP_VALUE, null);
	}

	//-------------------------------------------------------------------------
	private EditRightsHelper() {}
}

==> open-xchange-documents-backend_7.10.4.orig.tar.bz2: open-xchange-documents-backend-7.10.4/com.openexchange.office.rt2.core/src/com/openexchange/office/rt2/core/doc/EditRightsHelper.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.rt2.core.doc;

import org.json.JSONObject;

import com.openexchange.office.rt2.protocol.RT2Message;
import com.openexchange.office.rt2.protocol.value.RT2MessageType;

/**
 * Helper class to retrieve action and value from a "editrights"
 * request.
 *
 * @author Carsten Driesner
 *
 */
public class EditRightsHelper
{
	//-------------------------------------------------------------------------
	public static final String ACTION_EDITRIGHTS_REQUESTS = "request";

	//-------------------------------------------------------------------------
	public static final String ACTION_EDITRIGHTS_APPROVED = "approved";

	//-------------------------------------------------------------------------
	public static final String ACTION_EDITRIGHTS_DECLINED = "declined";

	//-------------------------------------------------------------------------
	public static final String ACTION_EDITRIGHTS_FORCE    = "force";

	//-------------------------------------------------------------------------
	public static final String ACTION_EDITRIGHTS_ALL      = "@ALL";

	//-------------------------------------------------------------------------
	public static String getAction(final RT2Message aMsg) throws Exception
	{
		if (RT2MessageType.REQUEST_EDITRIGHTS.equals(aMsg.getType())) {
			JSONObject body = aMsg.getBody();
			return body.getString(MessageProperties.PROP_ACTION);
		}
		throw new IllegalArgumentException("RT2Message is not a REQUEST_EDITRIGHTS");
	}

	//-------------------------------------------------------------------------
	public static String getActionValue(final RT2Message aMsg) throws Exception
	{
		if (RT2MessageType.REQUEST_EDITRIGHTS.equals(aMsg.getType())) {
			JSONObject body = aMsg.getBody();
			return body.optString(MessageProperties.PROP_VALUE, null);
		}
		throw new IllegalArgumentException("RT2Message is not a REQUEST_EDITRIGHTS");
	}

	//-------------------------------------------------------------------------
	public static String getAction(final JSONObject aMsgBody) throws Exception
	{
		return aMsgBody.getString(MessageProperties.PROP_ACTION);
	}

	//-------------------------------------------------------------------------
	public static String getActionValue(final JSONObject aMsgBody) throws Exception
	{
		return aMsgBody.optString(MessageProperties.PROP_VALUE, null);
	}

	//-------------------------------------------------------------------------
	private EditRightsHelper() {}
}
